@@ -8,6 +8,7 @@ import urlparse
 from distutils.spawn import find_executable
 
 from scalr_manage.library.configure import constant
+from scalr_manage.sentry.constant import RAVEN_DSN_ENV_VAR
 from scalr_manage.version import __version__
 
 
@@ -66,10 +67,25 @@ class Group(object):
         return {}
 
 
+class LoggingGroup(Group):
+    name        = "logging"
+    recipes     = ["chef-sentry-handler"]
+    priority    = 0
+    optional    = False  # This only gets enabled if the env var is set
+
+    @classmethod
+    def make_attributes(cls, args, ui, tokgen):
+        raven_dsn = os.environ.get(RAVEN_DSN_ENV_VAR)
+        return {"sentry": {
+            "enabled": raven_dsn is not None,
+            "dsn": raven_dsn
+        }}
+
+
 class UtilGroup(Group):
     name        = "util"
     recipes     = ["apt", "build-essential", "timezone-ii"]
-    priority    = 0
+    priority    = 5
     optional    = False
 
     @classmethod
@@ -237,6 +253,17 @@ class IptablesGroup(Group):
     priority    = 40
     optional    = True
 
+    @classmethod
+    def enabled_ip_versions(cls):
+        def enabled(ip_version, tables_path):
+            if os.path.exists(tables_path):
+                return True
+            logger.warning("Not enabling iptables management for IPv%s: protocol version appears to be disabled", ip_version)
+            return False
+
+        return [ip_version for ip_version, tables_path in constant.IPTABLES_VERSIONS_INDICATORS
+                if enabled(ip_version, tables_path)]
+
     @classmethod
     def make_attributes(cls, args, ui, tokgen):
         input_rules = {}
@@ -258,5 +285,8 @@ class IptablesGroup(Group):
                     "rule": "--protocol tcp --dport 8080 --match state --state NEW --jump ACCEPT"
                 },
             })
-        return {"iptables-ng": {"rules": {"filter": {"INPUT": input_rules}}}}
+        return {"iptables-ng": {
+            "enabled_ip_versions": cls.enabled_ip_versions(),
+            "rules": {"filter": {"INPUT": input_rules}}}
+        }
 
